# hiddifypanel 

 hiddifypanel to create multi proxy using xray mtproxy and others

## 🌎 Translations

<div align=center>
    
[![inlang status badge](https://inlang.com/badge?url=github.com/hiddify/hiddifypanel)](https://inlang.com/editor/github.com/hiddify/hiddifypanel?ref=badge)
</div>

Improve existing languages or add new ones by manually editing the JSON files located in `/assets/translations` or by using the [Inlang online editor](https://inlang.com/editor/github.com/hiddify/hiddifypanel).

# How to use it
Please visit https://github.com/hiddify/hiddify-manager/wiki for the installation.

# Source Code: https://github.com/hiddify/HiddifyPanel/
<!--
## Installation

From source:

```bash
git clone https://github.com/hiddify/HiddifyPanel hiddifypanel
cd hiddifypanel
make install
```

From pypi:

```bash
pip install hiddifypanel
```

## Executing

This application has a CLI interface that extends the Flask CLI.

Just run:

```bash
$ hiddifypanel
```

or

```bash
$ python -m hiddifypanel
```

To see the help message and usage instructions.

## First run

```bash
hiddifypanel init-db   # run once
echo localhost:9000/$(hiddifypanel admin-path)
hiddifypanel run
```


> **Note**: You can also use `flask run` to run the application.

-->
